@@ -19,13 +19,12 @@
  ***************************************************************************/
 
 #include "pingrsp.h"
-#include <util/log.h>
-#include <bcodec/bencoder.h>
 #include "dht.h"
+#include <bcodec/bencoder.h>
+#include <util/log.h>
 
 using namespace bt;
 
-
 namespace dht
 {
 PingRsp::PingRsp()
@@ -33,38 +32,42 @@ PingRsp::PingRsp()
 {
 }
 
-PingRsp::PingRsp(const QByteArray & mtid, const Key & id)
+PingRsp::PingRsp(const QByteArray &mtid, const Key &id)
     : RPCMsg(mtid, PING, RSP_MSG, id)
-{}
+{
+}
 
 PingRsp::~PingRsp()
-{}
+{
+}
 
-void PingRsp::apply(dht::DHT* dh_table)
+void PingRsp::apply(dht::DHT *dh_table)
 {
     dh_table->response(*this);
 }
 
 void PingRsp::print()
 {
-    Out(SYS_DHT | LOG_DEBUG) << QString("RSP: %1 %2 : ping")
-                             .arg(mtid[0]).arg(id.toString()) << endl;
+    Out(SYS_DHT | LOG_DEBUG) << QString("RSP: %1 %2 : ping").arg(mtid[0]).arg(id.toString()) << endl;
 }
 
-void PingRsp::encode(QByteArray & arr) const
+void PingRsp::encode(QByteArray &arr) const
 {
     BEncoder enc(new BEncoderBufferOutput(arr));
     enc.beginDict();
     {
-        enc.write(RSP); enc.beginDict();
+        enc.write(RSP);
+        enc.beginDict();
         {
-            enc.write(QByteArrayLiteral("id")); enc.write(id.getData(), 20);
+            enc.write(QByteArrayLiteral("id"));
+            enc.write(id.getData(), 20);
         }
         enc.end();
-        enc.write(TID); enc.write(mtid);
-        enc.write(TYP); enc.write(RSP);
+        enc.write(TID);
+        enc.write(mtid);
+        enc.write(TYP);
+        enc.write(RSP);
     }
     enc.end();
 }
 }
-
