@@ -18,39 +18,42 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
 #include "rpcserver.h"
-#include <QHostAddress>
-#include <QThread>
-#include <unistd.h>
-#include <string.h>
-#include <boost/scoped_ptr.hpp>
-#include <net/portlist.h>
-#include <util/log.h>
-#include <util/error.h>
-#include <torrent/globals.h>
-#include <bcodec/bnode.h>
-#include <bcodec/bdecoder.h>
-#include <bcodec/bencoder.h>
-#include <util/functions.h>
-#include <net/serversocket.h>
-#include "rpccall.h"
-#include "rpcmsg.h"
+#include "dht.h"
 #include "kbucket.h"
 #include "node.h"
-#include "dht.h"
 #include "pingreq.h"
+#include "rpccall.h"
+#include "rpcmsg.h"
 #include "rpcmsgfactory.h"
+#include <QHostAddress>
+#include <QThread>
+#include <bcodec/bdecoder.h>
+#include <bcodec/bencoder.h>
+#include <bcodec/bnode.h>
+#include <boost/scoped_ptr.hpp>
+#include <net/portlist.h>
+#include <net/serversocket.h>
+#include <string.h>
+#include <torrent/globals.h>
+#include <unistd.h>
+#include <util/error.h>
+#include <util/functions.h>
+#include <util/log.h>
 
 using namespace bt;
 
 namespace dht
 {
-
 class RPCServer::Private : public net::ServerSocket::DataHandler, public RPCMethodResolver
 {
 public:
-    Private(RPCServer* p, DHT* dh_table, Uint16 port)
-        : p(p), dh_table(dh_table), next_mtid(0), port(port)
-    {}
+    Private(RPCServer *p, DHT *dh_table, Uint16 port)
+        : p(p)
+        , dh_table(dh_table)
+        , next_mtid(0)
+        , port(port)
+    {
+    }
 
     ~Private() override
     {
@@ -66,7 +69,7 @@ public:
         sockets.clear();
     }
 
-    void listen(const QString & ip)
+    void listen(const QString &ip)
     {
         net::Address addr(ip, port);
         net::ServerSocket::Ptr sock(new net::ServerSocket(this));
@@ -79,7 +82,7 @@ public:
         }
     }
 
-    void dataReceived(bt::Buffer::Ptr ptr, const net::Address& addr) override
+    void dataReceived(bt::Buffer::Ptr ptr, const net::Address &addr) override
     {
         try {
             // read and decode the packet
@@ -90,7 +93,7 @@ public:
                 return;
 
             // try to make a RPCMsg of it
-            RPCMsg::Ptr msg = factory.build((BDictNode*)n.get(), this);
+            RPCMsg::Ptr msg = factory.build((BDictNode *)n.get(), this);
             if (msg) {
                 if (addr.ipVersion() == 6 && addr.isIPv4Mapped())
                     msg->setOrigin(addr.convertIPv4Mapped());
@@ -101,36 +104,36 @@ public:
                 // erase an existing call
                 if (msg->getType() == RSP_MSG && calls.contains(msg->getMTID())) {
                     // delete the call, but first notify it off the response
-                    RPCCall* c = calls.find(msg->getMTID());
+                    RPCCall *c = calls.find(msg->getMTID());
                     c->response(msg);
                     calls.erase(msg->getMTID());
                     c->deleteLater();
                     doQueuedCalls();
                 }
             }
-        } catch (bt::Error & err) {
+        } catch (bt::Error &err) {
             Out(SYS_DHT | LOG_DEBUG) << "Error happened during parsing : " << err.toString() << endl;
         }
     }
 
-    void readyToWrite(net::ServerSocket* sock) override
+    void readyToWrite(net::ServerSocket *sock) override
     {
         Q_UNUSED(sock);
     }
 
-    Method findMethod(const QByteArray& mtid) override
+    Method findMethod(const QByteArray &mtid) override
     {
-        const RPCCall* call = calls.find(mtid);
+        const RPCCall *call = calls.find(mtid);
         if (call)
             return call->getMsgMethod();
         else
             return dht::NONE;
     }
 
-    void send(const net::Address & addr, const QByteArray & msg)
+    void send(const net::Address &addr, const QByteArray &msg)
     {
         for (net::ServerSocket::Ptr sock : qAsConst(sockets)) {
-            if (sock->sendTo((const bt::Uint8*)msg.data(), msg.size(), addr) == msg.size())
+            if (sock->sendTo((const bt::Uint8 *)msg.data(), msg.size(), addr) == msg.size())
                 break;
         }
     }
@@ -138,7 +141,7 @@ public:
     void doQueuedCalls()
     {
         while (call_queue.count() > 0 && calls.count() < 256) {
-            RPCCall* c = call_queue.first();
+            RPCCall *c = call_queue.first();
             call_queue.removeFirst();
 
             while (calls.contains(QByteArray(1, next_mtid)))
@@ -154,7 +157,7 @@ public:
         }
     }
 
-    RPCCall* doCall(RPCMsg::Ptr msg)
+    RPCCall *doCall(RPCMsg::Ptr msg)
     {
         Uint8 start = next_mtid;
         QByteArray mtid(1, start);
@@ -163,7 +166,7 @@ public:
             mtid[0] = ++next_mtid;
             if (next_mtid == start) { // if this happens we cannot do any calls
                 // so queue the call
-                RPCCall* c = new RPCCall(msg, true);
+                RPCCall *c = new RPCCall(msg, true);
                 call_queue.append(c);
                 Out(SYS_DHT | LOG_NOTICE) << "Queueing RPC call, no slots available at the moment" << endl;
                 return c;
@@ -172,7 +175,7 @@ public:
 
         msg->setMTID(mtid);
         sendMsg(msg);
-        RPCCall* c = new RPCCall(msg, false);
+        RPCCall *c = new RPCCall(msg, false);
         calls.insert(mtid, c);
         return c;
     }
@@ -185,10 +188,10 @@ public:
         //  PrintRawData(data);
     }
 
-    void timedOut(const QByteArray & mtid)
+    void timedOut(const QByteArray &mtid)
     {
         // delete the call
-        RPCCall* c = calls.find(mtid);
+        RPCCall *c = calls.find(mtid);
         if (c) {
             dh_table->timeout(c->getRequest());
             calls.erase(mtid);
@@ -197,24 +200,22 @@ public:
         doQueuedCalls();
     }
 
-    RPCServer* p;
+    RPCServer *p;
     QList<net::ServerSocket::Ptr> sockets;
-    DHT* dh_table;
+    DHT *dh_table;
     bt::PtrMap<QByteArray, RPCCall> calls;
-    QList<RPCCall*> call_queue;
+    QList<RPCCall *> call_queue;
     bt::Uint8 next_mtid;
     bt::Uint16 port;
     RPCMsgFactory factory;
 };
 
-
-
-RPCServer::RPCServer(DHT* dh_table, Uint16 port, QObject *parent)
-    : QObject(parent), d(new Private(this, dh_table, port))
+RPCServer::RPCServer(DHT *dh_table, Uint16 port, QObject *parent)
+    : QObject(parent)
+    , d(new Private(this, dh_table, port))
 {
 }
 
-
 RPCServer::~RPCServer()
 {
     delete d;
@@ -225,7 +226,7 @@ void RPCServer::start()
     d->reset();
 
     const QStringList ips = NetworkInterfaceIPAddresses(NetworkInterface());
-    for (const QString & addr : ips) {
+    for (const QString &addr : ips) {
         d->listen(addr);
     }
 
@@ -261,9 +262,9 @@ static void PrintRawData(const QByteArray & data)
 }
 #endif
 
-RPCCall* RPCServer::doCall(RPCMsg::Ptr msg)
+RPCCall *RPCServer::doCall(RPCMsg::Ptr msg)
 {
-    RPCCall* c = d->doCall(msg);
+    RPCCall *c = d->doCall(msg);
     if (c)
         connect(c, &RPCCall::timeout, this, &RPCServer::callTimeout);
 
@@ -275,19 +276,19 @@ void RPCServer::sendMsg(RPCMsg::Ptr msg)
     d->sendMsg(msg);
 }
 
-void RPCServer::sendMsg(const dht::RPCMsg& msg)
+void RPCServer::sendMsg(const dht::RPCMsg &msg)
 {
     QByteArray data;
     msg.encode(data);
     d->send(msg.getDestination(), data);
 }
 
-void RPCServer::callTimeout(RPCCall* call)
+void RPCServer::callTimeout(RPCCall *call)
 {
     d->timedOut(call->getRequest()->getMTID());
 }
 
-void RPCServer::ping(const dht::Key & our_id, const net::Address & addr)
+void RPCServer::ping(const dht::Key &our_id, const net::Address &addr)
 {
     RPCMsg::Ptr pr(new PingReq(our_id));
     pr->setOrigin(addr);
@@ -299,4 +300,3 @@ Uint32 RPCServer::getNumActiveRPCCalls() const
     return d->calls.count();
 }
 }
-
